import { Link } from "@components/Link";
import clsx from "clsx";

export interface BreadcrumbsProps {
  crumbs?: Array<{
    href?: string;
    title?: string;
    icon?: React.ReactElement;
  }>;
  separator?: string;
  className?: string;
}
export function Breadcrumbs({
  crumbs,
  separator = "/",
  className = "",
}: BreadcrumbsProps) {
  return crumbs && Boolean(crumbs.length) ? (
    <div className={clsx("fs-inline-flex", className)}>
      {crumbs?.map((crumb, index) => (
        <div
          className={clsx(
            index === crumbs.length - 1
              ? "fs-font-inter fs-font-medium"
              : "fs-font-flex fs-font-normal",
            "fs-flex fs-text-sm fs-leading-5 fs-text-grey-500",
          )}
          key={"breadcrumb" + index}
        >
          {(crumb.icon || crumb.title) && (
            <Link
              to={crumb.href}
              className={clsx(
                "fs-flex-shrink-0 !fs-flex fs-gap-2 fs-items-center",
                crumb.href &&
                  "hover:fs-multi-line-underline fs-multi-line-grey-500 !fs-w-auto",
              )}
            >
              {crumb.icon || ""}
              {crumb.title || ""}
            </Link>
          )}
          {!crumb.icon && !crumb.title && "Unknown"}
          {index !== crumbs.length - 1 && (
            <div className="fs-font-flex fs-text-sm fs-leading-5 fs-font-normal fs-text-grey-500 fs-px-2">
              {separator}
            </div>
          )}
        </div>
      ))}
    </div>
  ) : null;
}
