import { ChevronRight, UserMultiple } from "@carbon/icons-react";
import { Link } from "./Link";

export interface MessageRoomProps {
  target: string;
  name: string;
  description: string;
  image: {
    src: string;
    alt: string;
  };
  members: number;
  tag: string;
}

export function MessageRoom({
  target,
  name,
  description,
  image,
  members,
  tag,
}: MessageRoomProps) {
  return (
    <Link
      className="fs-block fs-bg-white hover:fs-bg-grey-900 fs-border fs-border-transparent focus:fs-border-grey-900 fs-transition-colors fs-ease-in fs-duration-50"
      to={target}
    >
      <div className="fs-group fs-relative fs-flex fs-items-center fs-gap-3 fs-py-4 fs-px-5 sm:fs-px-6">
        <div className="fs-size-12 fs-rounded-full fs-overflow-hidden">
          <img
            className="fs-size-full fs-object-cover"
            alt={image.alt}
            src={image.src}
          />
        </div>
        <div className="fs-w-[calc(100%-3rem)] fs-flex fs-gap-4 sm:fs-pr-8 md:fs-pr-6 lg:fs-pr-10">
          <div className="fs-w-full sm:fs-w-1/4 md:fs-w-[30%] lg:fs-w-1/4">
            <div className="fs-font-plex fs-flex fs-flex-col fs-justify-between">
              <span className="fs-text-sm fs-leading-5 fs-font-medium fs-text-grey-900 fs-line-clamp-1 group-hover:fs-text-white fs-transition-colors fs-ease-in fs-duration-50">
                {name}
              </span>
              <span className="fs-text-xs fs-leading-4 fs-font-normal fs-text-grey-500 fs-break-all fs-line-clamp-1">
                {tag}
              </span>
              <span className="fs-flex fs-items-center fs-text-xs fs-leading-4 fs-font-normal fs-text-grey-500">
                <UserMultiple className="fs-mr-2" /> {members}
              </span>
            </div>
          </div>
          <div className="fs-hidden sm:fs-block w-[75%]">
            <p className="fs-font-plex fs-text-sm fs-leading-5 fs-font-normal fs-text-black fs-line-clamp-3 group-hover:fs-text-white fs-transition-colors fs-ease-in fs-duration-50">
              {description}
            </p>
          </div>
        </div>
        <ChevronRight
          size={24}
          className="fs-absolute fs-top-1/2 fs-right-4 lg:fs-right-6 -fs-translate-y-2/4 fs-text-grey-500"
        />
      </div>
    </Link>
  );
}
