import { Pill } from "@components/Pill";
import { Link } from "@components/Link";
import { INewsImage, INewsCategory } from "@interfaces/INews";
import { ConditionalWrapper } from "./ConditionalWrapper";
import clsx from "clsx";
type PillColor = "dark" | "white";

export interface MiniCardProps {
  name?: string;
  subtitle?: React.ReactNode;
  image: INewsImage;
  rightImage?: INewsImage;
  rightImageHref?: string;
  tags?: INewsCategory[];
  href?: string;
  type?: "light" | "dark";
  className?: string;
}

export function MiniCard({
  name,
  image,
  subtitle,
  tags,
  href,
  type = "light",
  className = "",
  rightImage,
  rightImageHref,
}: MiniCardProps) {
  const PILL_COLOR_MAPPING: Record<string, PillColor> = {
    dark: "white",
    light: "dark",
  };
  const imageEl = (
    <img
      className="fs-size-full fs-object-cover"
      alt={image.alt}
      src={image.src}
    />
  );
  const rightImageEl = rightImage && (
    <img
      className="fs-w-full fs-object-contain fs-min-w-8"
      src={rightImage.src}
      alt={rightImage.alt}
    />
  );
  const titleEl = (
    <h2 className="fs-not-prose fs-font-karla fs-text-base md:fs-text-3xl md:fs-leading-8 fs-font-bold fs-text-grey-900 md:fs-mb-2 fs-line-clamp-2">
      {name}
    </h2>
  );
  return (
    <div
      className={clsx(
        "fs-flex fs-bg-grey-100 fs-w-full md:fs-max-w-[820px] fs-h-[75px] md:fs-h-[180px]",
        className,
      )}
    >
      <div className="fs-h-full fs-aspect-square">
        <ConditionalWrapper
          condition={Boolean(href)}
          wrapper={(children) => (
            <Link to={href} className="fs-block fs-h-full fs-aspect-square">
              {children}
            </Link>
          )}
        >
          {imageEl}
        </ConditionalWrapper>
      </div>
      <div className="fs-relative fs-flex fs-gap-4 fs-px-2 fs-py-1 md:fs-px-8 md:fs-py-4 fs-size-full fs-justify-between fs-overflow-hidden">
        <div className="fs-flex fs-flex-col fs-justify-between">
          <div>
            {href ? <Link to={href}>{titleEl}</Link> : titleEl}
            {subtitle && (
              <span className="fs-text-sm fs-flex fs-flex-wrap fs-font-plex fs-font-normal fs-text-grey-500 fs-gap-1 md:fs-gap-2">
                {subtitle}
              </span>
            )}
          </div>
          {tags && (
            <div className="fs-hidden md:fs-flex fs-flex-wrap fs-gap-2">
              {tags.map((tag) => (
                <Pill
                  key={tag.title}
                  type={PILL_COLOR_MAPPING[type]}
                  size="sm"
                  rounded
                  href={tag.href}
                  title={tag.title}
                />
              ))}
            </div>
          )}
        </div>
        {rightImage && (
          <div className="fs-aspect-square fs-flex fs-items-start fs-justify-end">
            <ConditionalWrapper
              condition={Boolean(rightImageHref)}
              wrapper={(children) => (
                <Link
                  to={rightImageHref}
                  className="fs-block fs-h-full fs-aspect-square"
                >
                  {children}
                </Link>
              )}
            >
              {rightImageEl}
            </ConditionalWrapper>
          </div>
        )}
      </div>
    </div>
  );
}
