import React from "react";
import {
  LogoFacebook,
  LogoMastodon,
  LogoLinkedin,
  LogoTwitter,
  LogoX,
  LogoYoutube,
  LogoInstagram,
  LogoGithub,
  LogoGitlab,
  LogoXing,
  Home,
  Email,
} from "@carbon/icons-react";
import { CarbonIconType } from "@carbon/icons-react/lib/CarbonIcon";
import { SocialNetworks } from "@interfaces/IFooter";

const socialMediaPropMapping: Record<
  SocialNetworks,
  { icon?: CarbonIconType | (() => React.ReactElement); title: string }
> = {
  instagram: {
    icon: LogoInstagram,
    title: "Instagram",
  },
  twitter: {
    icon: LogoTwitter,
    title: "Twitter",
  },
  x: {
    icon: LogoX,
    title: "X",
  },
  youtube: {
    icon: LogoYoutube,
    title: "YouTube",
  },
  gitlab: {
    icon: LogoGitlab,
    title: "GitLab",
  },
  linkedin: {
    icon: LogoLinkedin,
    title: "LinkedIn",
  },
  mastodon: {
    icon: LogoMastodon,
    title: "Mastodon",
  },
  facebook: {
    icon: LogoFacebook,
    title: "Facebook",
  },
  xing: {
    icon: LogoXing,
    title: "Xing",
  },
  github: {
    icon: LogoGithub,
    title: "GitHub",
  },
  website: {
    icon: Home,
    title: "Website",
  },
  email: {
    icon: Email,
    title: "E-Mail",
  },
  bluesky: {
    icon: () => (
      <svg
        xmlns="http://www.w3.org/2000/svg"
        width="32"
        height="32"
        viewBox="0 0 32 32"
      >
        <path
          d="M7.847 5.034c3.3 2.478 6.85 7.501 8.153 10.197 1.303-2.696 4.853-7.72 8.153-10.197 2.381-1.788 6.239-3.171 6.239 1.231 0 .879-.504 7.384-.8 8.44-1.027 3.671-4.771 4.608-8.101 4.041 5.821.991 7.302 4.273 4.104 7.554-6.074 6.233-8.73-1.564-9.411-3.561-.125-.367-.183-.538-.184-.392-.001-.146-.059.025-.184.392-.681 1.997-3.337 9.794-9.411 3.561-3.198-3.281-1.717-6.563 4.104-7.554-3.33.567-7.074-.37-8.101-4.041-.296-1.056-.8-7.561-.8-8.44 0-4.402 3.858-3.019 6.239-1.231Z"
          fill="currentColor"
        />
      </svg>
    ),
    title: "Bluesky",
  },
};

export interface SocialMediaIconProps {
  type: SocialNetworks;
  href?: string;
  className?: string;
}

export function SocialMediaIcon({
  type,
  href,
  className,
}: SocialMediaIconProps) {
  const Component = socialMediaPropMapping?.[type]?.icon || React.Fragment;
  return href ? (
    <a
      className={className}
      href={`${type === "email" ? "mailto:" : ""}${href}`}
      target="_blank"
      rel="noreferrer"
    >
      <Component
        aria-label={socialMediaPropMapping?.[type].title}
        className="fs-size-full"
      />
    </a>
  ) : (
    <div className={className}>
      <Component
        aria-label={socialMediaPropMapping?.[type].title}
        className="fs-size-full"
      />
    </div>
  );
}
