import { GridCard } from "@components/GridCard";
import type { Story, StoryDefault } from "@ladle/react";
import { ArrowRight } from "@carbon/icons-react";

interface GridCardConfig {
  title: string;
  subtitle?: string;
  buttonCaption?: string;
  buttonTarget?: string;
  img?: string;
  imgAlt?: string;
  light?: boolean;
  children?: string;
}

export const GridCardStory: Story<GridCardConfig> = ({
  buttonCaption,
  light,
  title,
  subtitle,
  img,
  buttonTarget,
  imgAlt,
  children,
}: GridCardConfig) => (
  <div className="fs-grid fs-grid-rows-3 lg:fs-grid-cols-3 fs-gap-5">
    <GridCard
      title={title}
      subtitle={subtitle}
      buttonCaption={buttonCaption}
      buttonTarget={buttonTarget}
      img={img}
      imgAlt={imgAlt}
      light={light}
      icon={<ArrowRight />}
    >
      {children}
    </GridCard>
  </div>
);

GridCardStory.args = {
  light: false,
  title: "Something Interesting",
  subtitle: "More details here",
  buttonCaption: "Read more",
  img: "https://picsum.photos/id/1016/650/650",
  imgAlt: "Some Image description",
  children:
    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nunc lectus, lobortis ut justo et, tempus fermentum purus",
};

export default {
  title: "Molecules",
} satisfies StoryDefault;
GridCardStory.storyName = "Grid Card";
GridCardStory.meta = {
  descriptionTitle: "Grid Card",
  description:
    "This is a simple card component with dynamic width and two color variants. It is ideally used within a (one- or two-dimensional) grid of cards (but without interactivity/slider).",
};
