import { LogoGrid, Logo } from "@components/LogoGrid";
import Logo1 from "@assets/images/Logo_Ratio_2-1.svg";
import Logo2 from "@assets/images/Logo_Ratio_2-3.svg";
import Logo3 from "@assets/images/Logo_Ratio_3-2.svg";
import type { Story, StoryDefault } from "@ladle/react";

interface LogoGridConfigProps {
  columns: 2 | 3 | 4 | 5 | 6;
}

export const LogoGridStory: Story<LogoGridConfigProps> = ({
  columns,
}: LogoGridConfigProps) => (
  <div className="container fs-py-10">
    <LogoGrid title="Unsere Gründungsmitglieder" columns={columns}>
      {[...Array(18).keys()].map((i) => {
        const randomInterger = Math.floor(Math.random() * (3 - 1 + 1)) + 1;
        if (randomInterger === 2)
          return (
            <Logo
              key={i}
              src={Logo2}
              alt="FabCity Hamburg"
              href="https://www.google.de/"
            />
          );
        if (randomInterger === 3)
          return (
            <Logo
              key={i}
              src={Logo3}
              alt="FabCity Hamburg"
              href="https://www.google.de/"
            />
          );
        return <Logo key={i} src={Logo1} alt="FabCity Hamburg" />;
      })}
    </LogoGrid>
  </div>
);

LogoGridStory.argTypes = {
  columns: {
    options: [2, 3, 4, 5, 6],
    control: { type: "select" },
    defaultValue: 6,
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

LogoGridStory.storyName = "Logo grid";
LogoGridStory.meta = {
  descriptionTitle: "Logo grid",
  description:
    "The Logo grid is a composition of a Grid component, which can take many different images/logos, which can be linked to an external or internal page.",
};
