import { SocialMediaIcons } from "@components/SocialMediaIcons";
import { ISocialMediaItem } from "@interfaces/IFooter";
import { Story, StoryDefault } from "@ladle/react";
import clsx from "clsx";

interface SocialMediaIconsStoryProps {
  variant?: "dark" | "light";
  grow?: boolean;
  twitter?: boolean;
  instagram?: boolean;
  youtube?: boolean;
  x?: boolean;
  gitlab?: boolean;
  github?: boolean;
  linkedin?: boolean;
  mastodon?: boolean;
  facebook?: boolean;
  xing?: boolean;
  website?: boolean;
  email?: boolean;
  bluesky?: boolean;
}

export const SocialMediaIconsStory: Story<SocialMediaIconsStoryProps> = ({
  variant,
  instagram,
  twitter,
  youtube,
  x,
  gitlab,
  github,
  linkedin,
  mastodon,
  facebook,
  xing,
  website,
  email,
  bluesky,
  grow,
}: SocialMediaIconsStoryProps) => {
  const SOCIAL_MEDIA: Array<ISocialMediaItem | undefined> = [
    instagram
      ? { href: "https://www.instagram.com", type: "instagram" }
      : undefined,
    mastodon
      ? { href: "https://www.mastodon.social", type: "mastodon" }
      : undefined,
    facebook
      ? { href: "https://www.facebook.com", type: "facebook" }
      : undefined,
    twitter ? { href: "https://www.twitter.com", type: "twitter" } : undefined,
    x ? { href: "https://www.x.com", type: "x" } : undefined,
    gitlab ? { href: "https://www.gitlab.com", type: "gitlab" } : undefined,
    youtube ? { href: "https://www.youtube.com", type: "youtube" } : undefined,
    linkedin
      ? { href: "https://www.linkedin.com", type: "linkedin" }
      : undefined,
    xing ? { href: "https://www.xing.de", type: "xing" } : undefined,
    github ? { href: "https://www.github.com", type: "github" } : undefined,
    website ? { href: "https://www.google.de", type: "website" } : undefined,
    email ? { href: "test@example.com", type: "email" } : undefined,
    bluesky ? { href: "https://www.bluesky.com", type: "bluesky" } : undefined,
  ];

  return (
    <div className="fs-max-w-2xl">
      <div
        className={clsx(
          variant === "light" ? "fs-bg-grey-900" : "fs-white",
          "fs-p-4",
        )}
      >
        <SocialMediaIcons
          grow={grow}
          variant={variant}
          icons={SOCIAL_MEDIA.filter(Boolean) as ISocialMediaItem[]}
        />
      </div>
    </div>
  );
};

SocialMediaIconsStory.args = {
  twitter: true,
  instagram: true,
  youtube: true,
  x: false,
  gitlab: false,
  github: false,
  linkedin: false,
  mastodon: false,
  facebook: false,
  xing: false,
  website: false,
  email: false,
  bluesky: false,
  grow: false,
};

SocialMediaIconsStory.argTypes = {
  variant: {
    options: ["dark", "light"],
    control: { type: "radio" },
    defaultValue: "dark",
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

SocialMediaIconsStory.storyName = "Social Media Icons";
SocialMediaIconsStory.meta = {
  descriptionTitle: "Social Media Icons",
  description:
    "This renders a horizontal row of given Social Media icons in either dark or light theme. Supported are Instagram, Mastodon, Facebook, Twitter, X, GitLab, YouTube, LinkedIn, Xing, GitHub, Website and E-Mail.",
};
