import type { Story, StoryDefault } from "@ladle/react";
import { VerticalNewsCard } from "@components/VerticalNewsCard";
import { Color } from "@interfaces/INews";

interface VerticalNewsCardConfigProps {
  customBackgroundColor?: Color;
  textColor?: "dark" | "light";
  image: string;
  imageAlt: string;
  title: string;
  description: string;
  href: string;
  date: string;
  location: string;
  category: string;
  variant: "light" | "dark" | "undefined";
  externalLinkIndicator: string;
}

export const VerticalNewsCardStory: Story<VerticalNewsCardConfigProps> = ({
  customBackgroundColor,
  image,
  imageAlt,
  title,
  description,
  href,
  textColor,
  date,
  location,
  category,
  variant,
  externalLinkIndicator,
}: VerticalNewsCardConfigProps) => {
  return (
    <div className="fs-grid fs-grid-cols-2 fs-gap-6 md:fs-gap-10 fs-pb-8 fs-pr-6">
      {variant !== "undefined" ? (
        <VerticalNewsCard
          image={{ src: image, alt: imageAlt }}
          title={title}
          description={description}
          date={date}
          location={location}
          category={{ id: 1, title: category }}
          href={href}
          variant={variant}
          externalLinkIndicator={externalLinkIndicator}
        />
      ) : (
        <VerticalNewsCard
          image={{ src: image, alt: imageAlt }}
          title={title}
          description={description}
          date={date}
          location={location}
          category={{ id: 1, title: category }}
          href={href}
          customBackgroundColor={customBackgroundColor}
          textColor={textColor}
          externalLinkIndicator={externalLinkIndicator}
        />
      )}
    </div>
  );
};

VerticalNewsCardStory.args = {
  customBackgroundColor: "#fcba03",
  image: "https://picsum.photos/id/103/600/600",
  imageAlt: "Some description",
  href: "https://google.de",
  title: "Lorem ipsum dolor sit amet consectetur adipiscing",
  description:
    "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nunc lectus, lobortis ut justo et, tempus fermentum purus",
  date: "",
  location: "",
  category: "News",
  externalLinkIndicator: "bla",
};

VerticalNewsCardStory.argTypes = {
  textColor: {
    options: ["dark", "light"],
    control: { type: "radio" },
    defaultValue: "light",
  },
  variant: {
    options: ["dark", "light", undefined],
    control: { type: "radio" },
    defaultValue: "dark",
  },
};

export default {
  title: "Molecules",
} satisfies StoryDefault;

VerticalNewsCardStory.storyName = "Vertical News Card";
VerticalNewsCardStory.meta = {
  descriptionTitle: "Vertical News Card",
  description:
    "This is a card element which can either display title, subtitle and description or alternatively it can show a date and location with icons. It is also a link, and can display a little indicator pill in the middle of the card (e.g. to visualize an external link). It is to be used in a horizontal context (e.g. a Grid or a Slider).",
};
