/* eslint-disable @typescript-eslint/no-var-requires */
/** @type {import('tailwindcss').Config} */
const plugin = require("tailwindcss/plugin");
const {
  default: flattenColorPalette,
} = require("tailwindcss/lib/util/flattenColorPalette");

module.exports = {
  prefix: "fs-",
  content: ["./src/**/*.{js,jsx,ts,tsx}", "./src/**/*.stories.{js,jsx,ts,tsx}"],
  theme: {
    fontFamily: {
      plex: ["var(--plex-font, 'IBM Plex Sans')", "sans-serif"],
      karla: ["var(--karla-font, 'Karla')", "sans-serif"],
      inter: ["var(--inter-font, 'Inter')", "sans-serif"],
    },
    colors: {
      black: "#000000",
      white: "#ffffff",
      transparent: "transparent",
      grey: {
        50: "#FDFDFC",
        100: "#F0F1F1",
        200: "#E4E4E5",
        400: "#A4A7AC",
        500: "#8A8E96",
        600: "#71767F",
        700: "#4B515D",
        900: "#0B1324",
      },
      pearl: {
        200: "#F9F7F4",
        500: "#EFEAE4",
        800: "#605E5B",
      },
      green: {
        500: "#35A58E",
      },
      red: {
        100: "#FBD8D7",
        500: "#EB4544",
        700: "#AC1312",
      },
      blue: {
        50: "#CBD9F1",
        500: "#3A70CA",
        700: "#1F3F74",
      },
      teal: {
        100: "#CCE4DF",
        700: "#014838",
      },
      amber: {
        100: "#FCF2DC",
        700: "#91712F",
      },
      purple: {
        100: "#EDE9FE",
        400: "#A78BFA",
        800: "#5B21B6",
      },
      pink: {
        100: "#FCE7F3",
        400: "#F472B6",
        800: "#9D174D",
      },
      slate: {
        900: "#0f172a",
      },
    },
    extend: {
      gridTemplateColumns: {
        // See: https://www.joshwcomeau.com/css/full-bleed/
        article: "1fr min(80ch, calc(100% - 32px)) 1fr;",
      },
    },
  },
  plugins: [
    require("@tailwindcss/typography"),
    // eslint-disable-next-line @typescript-eslint/no-var-requires
    require("tailwindcss-scoped-groups")({ groups: ["one", "two"] }),
    // Source: https://github.com/tailwindlabs/tailwindcss/pull/4556#issuecomment-1174799836
    plugin(function groupPeer({ addVariant }) {
      let pseudoVariants = ["checked", "hover"].map((variant) =>
        Array.isArray(variant) ? variant : [variant, `&:${variant}`],
      );
      for (let [variantName, state] of pseudoVariants) {
        addVariant(`group-peer-${variantName}`, (ctx) => {
          let result = typeof state === "function" ? state(ctx) : state;
          return result.replace(/&(\S+)/, ":merge(.peer)$1 ~ .group &");
        });
      }
    }),
    // Multi-line underline's custom classes
    plugin(function ({ matchUtilities, addUtilities, theme }) {
      const baseStyles = {
        width: "100%",
        display: "initial",
        "background-repeat": "no-repeat",
        "background-size": "0% 100%",
        "padding-bottom": "4px",
        transition: "background-size ease-in-out 300ms",
      };
      matchUtilities(
        {
          "multi-line": (value) => ({
            ...baseStyles,
            "background-image": `linear-gradient(transparent calc(100% - 1.5px), ${value} 1.5px)`,
          }),
          "multi-line-2": (value) => ({
            ...baseStyles,
            "background-image": `linear-gradient(transparent calc(100% - 2px), ${value} 2px)`,
          }),
          "multi-line-3": (value) => ({
            ...baseStyles,
            "background-image": `linear-gradient(transparent calc(100% - 3px), ${value} 3px)`,
          }),
        },
        { values: flattenColorPalette(theme("colors")) },
      );
      addUtilities([
        {
          ".multi-line-underline": {
            "background-size": "100% 100%",
          },
        },
      ]);
    }),
  ],
};
